import React, { Component } from 'react';
import style from './PDP.module.scss';
import ProductDetails from 'models/productDetail';
import ImageCarousel from 'components/ImageCarousel';
import Breadcrumb from 'components/Breadcrumb';

class PDPPage extends Component {

    state = {
        showImageCarousel: false
    };

    breadcrumb = [
        { name: 'home', url: '/' },
        { name: 'All New', url: '/shop/new' },
    ];

    componentDidMount() {
        const { match: { params: { productId } } } = this.props;
        this.props.getProductDetails(productId);
    }

    toggleImageCarouselClose = () => {
        const { showImageCarousel } = this.state;
        this.setState({ showImageCarousel: !showImageCarousel });
    }

    render() {
        const { product } = this.props;
        const { showImageCarousel } = this.state;
        const { name, image, sellingPrice, images } = new ProductDetails(product);
        const breadcrumbData = [...this.breadcrumb, { name, url: '#' }];
        return (
            <section className={style.PDPPage}>
                <Breadcrumb items={breadcrumbData} />
                <div className={style.content}>
                    <div className={style.images} onClick={this.toggleImageCarouselClose}>
                        <img
                            src={image.url}
                            alt={image.alt}
                            className={style.productImage}
                        />
                    </div>
                    <div className={style.details}>
                        <h1>{name}</h1>
                        <div className={style.sellingPrice}>{`Price: ${sellingPrice}`}</div>
                    </div>
                </div>
                <ImageCarousel
                    show={showImageCarousel}
                    images={images}
                    onClose={this.toggleImageCarouselClose}
                />
            </section>
        );
    }

}

export default PDPPage;